pub struct SessionStore {
pub dir: PathBuf,
pub manifest: SessionManifest,
}Expand description
Persistent session storage backed by JSONL files.
Fields
dir: PathBufRoot directory for this session.
manifest: SessionManifestSession manifest.
Implementations
Sourceimpl SessionStore
impl SessionStore
Sourcepub fn find_recent_for_cwd() -> Option<SessionManifest>
pub fn find_recent_for_cwd() -> Option<SessionManifest>
Find the most recent session for the current working directory.
Only returns sessions modified within max_age (default 24h).
PMAT-165: age filter prevents offering stale sessions.
Sourcepub fn find_recent_for_cwd_within(max_age: Duration) -> Option<SessionManifest>
pub fn find_recent_for_cwd_within(max_age: Duration) -> Option<SessionManifest>
Find the most recent session for cwd within the given age limit.
Sourcepub fn append_message(&self, msg: &Message) -> Result<()>
pub fn append_message(&self, msg: &Message) -> Result<()>
Append a message to the JSONL log.
Sourcepub fn append_messages(&self, msgs: &[Message]) -> Result<()>
pub fn append_messages(&self, msgs: &[Message]) -> Result<()>
Append multiple messages (e.g., after a turn completes).
Sourcepub fn load_messages(&self) -> Result<Vec<Message>>
pub fn load_messages(&self) -> Result<Vec<Message>>
Load all messages from the JSONL log.
Sourcepub fn record_turn(&mut self) -> Result<()>
pub fn record_turn(&mut self) -> Result<()>
Update the turn count in the manifest.