Module cache

Module cache 

Finding cache with mtime-based invalidation for bug-hunter.

Caches findings to disk using FNV-1a hashed keys. Invalidates when any source file under the project is newer than the cache file.

Structs

CachedFindings
Cached findings stored on disk.

Functions

any_source_newer_than
Check if any .rs source file under project_path is newer than cache_mtime.
cache_key
Compute an FNV-1a hash of the cache-relevant config fields.
load_cached
Load cached findings if the cache exists and is still valid.
save_cache
Save findings to the cache.