pub fn find_implementations(
claim: &SpecClaim,
project_path: &Path,
) -> Vec<CodeLocation>Expand description
Find code implementing a spec claim by searching for the claim ID in comments.
pub fn find_implementations(
claim: &SpecClaim,
project_path: &Path,
) -> Vec<CodeLocation>Find code implementing a spec claim by searching for the claim ID in comments.