pub struct BackendSelector {
pub privacy: PrivacyTier,
pub latency: LatencyTier,
pub throughput: ThroughputTier,
pub cost: CostTier,
pub disabled: HashSet<ServingBackend>,
pub preferred: Vec<ServingBackend>,
}Expand description
Backend selection configuration
Fields
privacy: PrivacyTierlatency: LatencyTierthroughput: ThroughputTiercost: CostTierdisabled: HashSet<ServingBackend>Explicitly disabled backends
preferred: Vec<ServingBackend>Preferred backends (tried first)
Implementations
Sourceimpl BackendSelector
impl BackendSelector
Sourcepub fn with_privacy(self, tier: PrivacyTier) -> Self
pub fn with_privacy(self, tier: PrivacyTier) -> Self
Set privacy tier
Sourcepub fn with_latency(self, tier: LatencyTier) -> Self
pub fn with_latency(self, tier: LatencyTier) -> Self
Set latency tier
Sourcepub fn with_throughput(self, tier: ThroughputTier) -> Self
pub fn with_throughput(self, tier: ThroughputTier) -> Self
Set throughput tier
Sourcepub fn disable(self, backend: ServingBackend) -> Self
pub fn disable(self, backend: ServingBackend) -> Self
Disable a specific backend
Sourcepub fn prefer(self, backend: ServingBackend) -> Self
pub fn prefer(self, backend: ServingBackend) -> Self
Add a preferred backend
Sourcepub fn recommend(&self) -> Vec<ServingBackend>
pub fn recommend(&self) -> Vec<ServingBackend>
Recommend backends based on requirements
Sourcepub fn is_valid(&self, backend: ServingBackend) -> bool
pub fn is_valid(&self, backend: ServingBackend) -> bool
Check if a backend is valid for current configuration
Sourcepub fn validate(&self, backend: ServingBackend) -> Result<(), PrivacyViolation>
pub fn validate(&self, backend: ServingBackend) -> Result<(), PrivacyViolation>
Validate a request against privacy tier (Poka-Yoke gate)
Returns Err if the backend would violate privacy constraints.