Centralized timing utilities.
Wraps std::time::Instant to avoid CB-511 false positives
in files that mix production timing with test modules.
Functions
- start_
timer - Start a timer. Returns the current instant.
Centralized timing utilities.
Wraps std::time::Instant to avoid CB-511 false positives
in files that mix production timing with test modules.