Finding cache with mtime-based invalidation for bug-hunter.
Caches findings to disk using FNV-1a hashed keys. Invalidates when any source file under the project is newer than the cache file.
Structs
- Cached
Findings - Cached findings stored on disk.
Functions
- any_
source_ newer_ than - Check if any
.rssource file underproject_pathis newer thancache_mtime. - cache_
key - Compute an FNV-1a hash of the cache-relevant config fields.
- load_
cached - Load cached findings if the cache exists and is still valid.
- save_
cache - Save findings to the cache.