pub fn load_cached(
project_path: &Path,
config: &HuntConfig,
) -> Option<CachedFindings>Expand description
Load cached findings if the cache exists and is still valid.
Returns None if the cache file doesn’t exist, is corrupt, or if any
source file has been modified since the cache was written.