Bug Hunter Diff Mode
Compare findings against a baseline to show only new issues.
Structs
- Baseline
- Baseline storage for diff comparisons.
- Diff
Result - Diff result showing new and resolved findings.
Functions
- filter_
changed_ files - Filter findings to only those in changed files.
- filter_
new_ findings - Filter findings to only include new ones.
- get_
changed_ files - Get files changed since a commit or time period.